## AWS C S3

C99 library implementation for communicating with the S3 service, designed for maximizing throughput on high bandwidth EC2 instances.

## License

This library is licensed under the Apache 2.0 License. 
